--- taxonomy_v1.php	2007-10-23 14:17:39.000000000 +0200
+++ taxonomy.php	2007-10-23 14:16:01.000000000 +0200
@@ -3,3 +3,3 @@
 //
 // Taxonomy Registration - modif by michelwp 071021 - #5230 and #5240 diff -
 //
@@ -506,2 +506,6 @@
 		$orderby = 't.name';
+	else if ( 'slug' == $orderby )
+		$orderby = 't.slug';
+	else if ( 'term_group' == $orderby )
+		$orderby = 't.term_group';
 	else
@@ -3,3 +3,3 @@
 //
-// Taxonomy Registration - modif by michelwp 071021 - #5230 and #5240 diff -
+// Taxonomy Registration - modif by michelwp 071023 - orderby in get_terms -
 //

